==> istio-model-v1beta1-6.1.0-sources.jar: io/fabric8/istio/api/security/v1beta1/SourceFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface SourceFluent<A extends SourceFluent<A>> extends Fluent<A>{
  public A addToIpBlocks(Integer index,String item);
  public A setToIpBlocks(Integer index,String item);
  public A addToIpBlocks(java.lang.String... items);
  public A addAllToIpBlocks(Collection<String> items);
  public A removeFromIpBlocks(java.lang.String... items);
  public A removeAllFromIpBlocks(Collection<String> items);
  public List<String> getIpBlocks();
  public String getIpBlock(Integer index);
  public String getFirstIpBlock();
  public String getLastIpBlock();
  public String getMatchingIpBlock(Predicate<String> predicate);
  public Boolean hasMatchingIpBlock(Predicate<String> predicate);
  public A withIpBlocks(List<String> ipBlocks);
  public A withIpBlocks(java.lang.String... ipBlocks);
  public Boolean hasIpBlocks();
  public A addToNamespaces(Integer index,String item);
  public A setToNamespaces(Integer index,String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(Collection<String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(Collection<String> items);
  public List<String> getNamespaces();
  public String getNamespace(Integer index);
  public String getFirstNamespace();
  public String getLastNamespace();
  public String getMatchingNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNamespace(Predicate<String> predicate);
  public A withNamespaces(List<String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public Boolean hasNamespaces();
  public A addToNotIpBlocks(Integer index,String item);
  public A setToNotIpBlocks(Integer index,String item);
  public A addToNotIpBlocks(java.lang.String... items);
  public A addAllToNotIpBlocks(Collection<String> items);
  public A removeFromNotIpBlocks(java.lang.String... items);
  public A removeAllFromNotIpBlocks(Collection<String> items);
  public List<String> getNotIpBlocks();
  public String getNotIpBlock(Integer index);
  public String getFirstNotIpBlock();
  public String getLastNotIpBlock();
  public String getMatchingNotIpBlock(Predicate<String> predicate);
  public Boolean hasMatchingNotIpBlock(Predicate<String> predicate);
  public A withNotIpBlocks(List<String> notIpBlocks);
  public A withNotIpBlocks(java.lang.String... notIpBlocks);
  public Boolean hasNotIpBlocks();
  public A addToNotNamespaces(Integer index,String item);
  public A setToNotNamespaces(Integer index,String item);
  public A addToNotNamespaces(java.lang.String... items);
  public A addAllToNotNamespaces(Collection<String> items);
  public A removeFromNotNamespaces(java.lang.String... items);
  public A removeAllFromNotNamespaces(Collection<String> items);
  public List<String> getNotNamespaces();
  public String getNotNamespace(Integer index);
  public String getFirstNotNamespace();
  public String getLastNotNamespace();
  public String getMatchingNotNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNotNamespace(Predicate<String> predicate);
  public A withNotNamespaces(List<String> notNamespaces);
  public A withNotNamespaces(java.lang.String... notNamespaces);
  public Boolean hasNotNamespaces();
  public A addToNotPrincipals(Integer index,String item);
  public A setToNotPrincipals(Integer index,String item);
  public A addToNotPrincipals(java.lang.String... items);
  public A addAllToNotPrincipals(Collection<String> items);
  public A removeFromNotPrincipals(java.lang.String... items);
  public A removeAllFromNotPrincipals(Collection<String> items);
  public List<String> getNotPrincipals();
  public String getNotPrincipal(Integer index);
  public String getFirstNotPrincipal();
  public String getLastNotPrincipal();
  public String getMatchingNotPrincipal(Predicate<String> predicate);
  public Boolean hasMatchingNotPrincipal(Predicate<String> predicate);
  public A withNotPrincipals(List<String> notPrincipals);
  public A withNotPrincipals(java.lang.String... notPrincipals);
  public Boolean hasNotPrincipals();
  public A addToNotRemoteIpBlocks(Integer index,String item);
  public A setToNotRemoteIpBlocks(Integer index,String item);
  public A addToNotRemoteIpBlocks(java.lang.String... items);
  public A addAllToNotRemoteIpBlocks(Collection<String> items);
  public A removeFromNotRemoteIpBlocks(java.lang.String... items);
  public A removeAllFromNotRemoteIpBlocks(Collection<String> items);
  public List<String> getNotRemoteIpBlocks();
  public String getNotRemoteIpBlock(Integer index);
  public String getFirstNotRemoteIpBlock();
  public String getLastNotRemoteIpBlock();
  public String getMatchingNotRemoteIpBlock(Predicate<String> predicate);
  public Boolean hasMatchingNotRemoteIpBlock(Predicate<String> predicate);
  public A withNotRemoteIpBlocks(List<String> notRemoteIpBlocks);
  public A withNotRemoteIpBlocks(java.lang.String... notRemoteIpBlocks);
  public Boolean hasNotRemoteIpBlocks();
  public A addToNotRequestPrincipals(Integer index,String item);
  public A setToNotRequestPrincipals(Integer index,String item);
  public A addToNotRequestPrincipals(java.lang.String... items);
  public A addAllToNotRequestPrincipals(Collection<String> items);
  public A removeFromNotRequestPrincipals(java.lang.String... items);
  public A removeAllFromNotRequestPrincipals(Collection<String> items);
  public List<String> getNotRequestPrincipals();
  public String getNotRequestPrincipal(Integer index);
  public String getFirstNotRequestPrincipal();
  public String getLastNotRequestPrincipal();
  public String getMatchingNotRequestPrincipal(Predicate<String> predicate);
  public Boolean hasMatchingNotRequestPrincipal(Predicate<String> predicate);
  public A withNotRequestPrincipals(List<String> notRequestPrincipals);
  public A withNotRequestPrincipals(java.lang.String... notRequestPrincipals);
  public Boolean hasNotRequestPrincipals();
  public A addToPrincipals(Integer index,String item);
  public A setToPrincipals(Integer index,String item);
  public A addToPrincipals(java.lang.String... items);
  public A addAllToPrincipals(Collection<String> items);
  public A removeFromPrincipals(java.lang.String... items);
  public A removeAllFromPrincipals(Collection<String> items);
  public List<String> getPrincipals();
  public String getPrincipal(Integer index);
  public String getFirstPrincipal();
  public String getLastPrincipal();
  public String getMatchingPrincipal(Predicate<String> predicate);
  public Boolean hasMatchingPrincipal(Predicate<String> predicate);
  public A withPrincipals(List<String> principals);
  public A withPrincipals(java.lang.String... principals);
  public Boolean hasPrincipals();
  public A addToRemoteIpBlocks(Integer index,String item);
  public A setToRemoteIpBlocks(Integer index,String item);
  public A addToRemoteIpBlocks(java.lang.String... items);
  public A addAllToRemoteIpBlocks(Collection<String> items);
  public A removeFromRemoteIpBlocks(java.lang.String... items);
  public A removeAllFromRemoteIpBlocks(Collection<String> items);
  public List<String> getRemoteIpBlocks();
  public String getRemoteIpBlock(Integer index);
  public String getFirstRemoteIpBlock();
  public String getLastRemoteIpBlock();
  public String getMatchingRemoteIpBlock(Predicate<String> predicate);
  public Boolean hasMatchingRemoteIpBlock(Predicate<String> predicate);
  public A withRemoteIpBlocks(List<String> remoteIpBlocks);
  public A withRemoteIpBlocks(java.lang.String... remoteIpBlocks);
  public Boolean hasRemoteIpBlocks();
  public A addToRequestPrincipals(Integer index,String item);
  public A setToRequestPrincipals(Integer index,String item);
  public A addToRequestPrincipals(java.lang.String... items);
  public A addAllToRequestPrincipals(Collection<String> items);
  public A removeFromRequestPrincipals(java.lang.String... items);
  public A removeAllFromRequestPrincipals(Collection<String> items);
  public List<String> getRequestPrincipals();
  public String getRequestPrincipal(Integer index);
  public String getFirstRequestPrincipal();
  public String getLastRequestPrincipal();
  public String getMatchingRequestPrincipal(Predicate<String> predicate);
  public Boolean hasMatchingRequestPrincipal(Predicate<String> predicate);
  public A withRequestPrincipals(List<String> requestPrincipals);
  public A withRequestPrincipals(java.lang.String... requestPrincipals);
  public Boolean hasRequestPrincipals();
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/SourceFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface SourceFluent<A extends SourceFluent<A>> extends Fluent<A>{
  public A addToIpBlocks(int index,String item);
  public A setToIpBlocks(int index,String item);
  public A addToIpBlocks(java.lang.String... items);
  public A addAllToIpBlocks(Collection<String> items);
  public A removeFromIpBlocks(java.lang.String... items);
  public A removeAllFromIpBlocks(Collection<String> items);
  public List<String> getIpBlocks();
  public String getIpBlock(int index);
  public String getFirstIpBlock();
  public String getLastIpBlock();
  public String getMatchingIpBlock(Predicate<String> predicate);
  public Boolean hasMatchingIpBlock(Predicate<String> predicate);
  public A withIpBlocks(List<String> ipBlocks);
  public A withIpBlocks(java.lang.String... ipBlocks);
  public Boolean hasIpBlocks();
  public A addToNamespaces(int index,String item);
  public A setToNamespaces(int index,String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(Collection<String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(Collection<String> items);
  public List<String> getNamespaces();
  public String getNamespace(int index);
  public String getFirstNamespace();
  public String getLastNamespace();
  public String getMatchingNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNamespace(Predicate<String> predicate);
  public A withNamespaces(List<String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public Boolean hasNamespaces();
  public A addToNotIpBlocks(int index,String item);
  public A setToNotIpBlocks(int index,String item);
  public A addToNotIpBlocks(java.lang.String... items);
  public A addAllToNotIpBlocks(Collection<String> items);
  public A removeFromNotIpBlocks(java.lang.String... items);
  public A removeAllFromNotIpBlocks(Collection<String> items);
  public List<String> getNotIpBlocks();
  public String getNotIpBlock(int index);
  public String getFirstNotIpBlock();
  public String getLastNotIpBlock();
  public String getMatchingNotIpBlock(Predicate<String> predicate);
  public Boolean hasMatchingNotIpBlock(Predicate<String> predicate);
  public A withNotIpBlocks(List<String> notIpBlocks);
  public A withNotIpBlocks(java.lang.String... notIpBlocks);
  public Boolean hasNotIpBlocks();
  public A addToNotNamespaces(int index,String item);
  public A setToNotNamespaces(int index,String item);
  public A addToNotNamespaces(java.lang.String... items);
  public A addAllToNotNamespaces(Collection<String> items);
  public A removeFromNotNamespaces(java.lang.String... items);
  public A removeAllFromNotNamespaces(Collection<String> items);
  public List<String> getNotNamespaces();
  public String getNotNamespace(int index);
  public String getFirstNotNamespace();
  public String getLastNotNamespace();
  public String getMatchingNotNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNotNamespace(Predicate<String> predicate);
  public A withNotNamespaces(List<String> notNamespaces);
  public A withNotNamespaces(java.lang.String... notNamespaces);
  public Boolean hasNotNamespaces();
  public A addToNotPrincipals(int index,String item);
  public A setToNotPrincipals(int index,String item);
  public A addToNotPrincipals(java.lang.String... items);
  public A addAllToNotPrincipals(Collection<String> items);
  public A removeFromNotPrincipals(java.lang.String... items);
  public A removeAllFromNotPrincipals(Collection<String> items);
  public List<String> getNotPrincipals();
  public String getNotPrincipal(int index);
  public String getFirstNotPrincipal();
  public String getLastNotPrincipal();
  public String getMatchingNotPrincipal(Predicate<String> predicate);
  public Boolean hasMatchingNotPrincipal(Predicate<String> predicate);
  public A withNotPrincipals(List<String> notPrincipals);
  public A withNotPrincipals(java.lang.String... notPrincipals);
  public Boolean hasNotPrincipals();
  public A addToNotRemoteIpBlocks(int index,String item);
  public A setToNotRemoteIpBlocks(int index,String item);
  public A addToNotRemoteIpBlocks(java.lang.String... items);
  public A addAllToNotRemoteIpBlocks(Collection<String> items);
  public A removeFromNotRemoteIpBlocks(java.lang.String... items);
  public A removeAllFromNotRemoteIpBlocks(Collection<String> items);
  public List<String> getNotRemoteIpBlocks();
  public String getNotRemoteIpBlock(int index);
  public String getFirstNotRemoteIpBlock();
  public String getLastNotRemoteIpBlock();
  public String getMatchingNotRemoteIpBlock(Predicate<String> predicate);
  public Boolean hasMatchingNotRemoteIpBlock(Predicate<String> predicate);
  public A withNotRemoteIpBlocks(List<String> notRemoteIpBlocks);
  public A withNotRemoteIpBlocks(java.lang.String... notRemoteIpBlocks);
  public Boolean hasNotRemoteIpBlocks();
  public A addToNotRequestPrincipals(int index,String item);
  public A setToNotRequestPrincipals(int index,String item);
  public A addToNotRequestPrincipals(java.lang.String... items);
  public A addAllToNotRequestPrincipals(Collection<String> items);
  public A removeFromNotRequestPrincipals(java.lang.String... items);
  public A removeAllFromNotRequestPrincipals(Collection<String> items);
  public List<String> getNotRequestPrincipals();
  public String getNotRequestPrincipal(int index);
  public String getFirstNotRequestPrincipal();
  public String getLastNotRequestPrincipal();
  public String getMatchingNotRequestPrincipal(Predicate<String> predicate);
  public Boolean hasMatchingNotRequestPrincipal(Predicate<String> predicate);
  public A withNotRequestPrincipals(List<String> notRequestPrincipals);
  public A withNotRequestPrincipals(java.lang.String... notRequestPrincipals);
  public Boolean hasNotRequestPrincipals();
  public A addToPrincipals(int index,String item);
  public A setToPrincipals(int index,String item);
  public A addToPrincipals(java.lang.String... items);
  public A addAllToPrincipals(Collection<String> items);
  public A removeFromPrincipals(java.lang.String... items);
  public A removeAllFromPrincipals(Collection<String> items);
  public List<String> getPrincipals();
  public String getPrincipal(int index);
  public String getFirstPrincipal();
  public String getLastPrincipal();
  public String getMatchingPrincipal(Predicate<String> predicate);
  public Boolean hasMatchingPrincipal(Predicate<String> predicate);
  public A withPrincipals(List<String> principals);
  public A withPrincipals(java.lang.String... principals);
  public Boolean hasPrincipals();
  public A addToRemoteIpBlocks(int index,String item);
  public A setToRemoteIpBlocks(int index,String item);
  public A addToRemoteIpBlocks(java.lang.String... items);
  public A addAllToRemoteIpBlocks(Collection<String> items);
  public A removeFromRemoteIpBlocks(java.lang.String... items);
  public A removeAllFromRemoteIpBlocks(Collection<String> items);
  public List<String> getRemoteIpBlocks();
  public String getRemoteIpBlock(int index);
  public String getFirstRemoteIpBlock();
  public String getLastRemoteIpBlock();
  public String getMatchingRemoteIpBlock(Predicate<String> predicate);
  public Boolean hasMatchingRemoteIpBlock(Predicate<String> predicate);
  public A withRemoteIpBlocks(List<String> remoteIpBlocks);
  public A withRemoteIpBlocks(java.lang.String... remoteIpBlocks);
  public Boolean hasRemoteIpBlocks();
  public A addToRequestPrincipals(int index,String item);
  public A setToRequestPrincipals(int index,String item);
  public A addToRequestPrincipals(java.lang.String... items);
  public A addAllToRequestPrincipals(Collection<String> items);
  public A removeFromRequestPrincipals(java.lang.String... items);
  public A removeAllFromRequestPrincipals(Collection<String> items);
  public List<String> getRequestPrincipals();
  public String getRequestPrincipal(int index);
  public String getFirstRequestPrincipal();
  public String getLastRequestPrincipal();
  public String getMatchingRequestPrincipal(Predicate<String> predicate);
  public Boolean hasMatchingRequestPrincipal(Predicate<String> predicate);
  public A withRequestPrincipals(List<String> requestPrincipals);
  public A withRequestPrincipals(java.lang.String... requestPrincipals);
  public Boolean hasRequestPrincipals();
  
}
